psychopy_ext.fmri.Analysis.run — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.Analysis.run

`Analysis.` `run`()

  A wrapper for running an analysis specified in self.rp.

  Steps:
    - Try to load a saved analysis, unless any force flag is given
    - Otherwise, either generate synthetic data (values = sim) or extract it from the real data using `run_method()`.
    - Save a pandas.DataFrame in the analysis folder with the filename like df_<method>_<values>.pkl

  Returns: | A DataFrame with the output of a particular analysis in the subj_resp column, and a file name where that data is stored.